@@ -20,6 +20,7 @@ import {
   ListItemSecondaryAction
 } from 'system/components'
 import {
+  ListField,
   ListsSelection,
   ProvListProps,
 } from './types'
@@ -42,7 +43,8 @@ type ProvListItemPrepared = {
   key: CommonKey | undefined
   routePath: string | null
   divider: boolean
-  primaryField: string
+  primaryField: ListField | null
+  secondaryField: ListField | null
   itemAltText: string | undefined
   avatarUrl: string | null
   avatarChildren: JSX.Element | JSX.Element[] | string | null
@@ -143,8 +145,11 @@ export class ProvList extends React.Component<ProvListProps, ProvListState> {
   private getItemAvatarColor = (item: any, itemAlt: string | undefined): string | undefined => {
     if (typeof this.props.avatarColor == 'function')
       return this.props.avatarColor(item)
-    if (typeof this.props.avatarColor == 'string')
+    if (typeof this.props.avatarColor == 'string') {
+      if (this.props.avatarColor in item)
+        return item[this.props.avatarColor]
       return this.props.avatarColor
+    }
     if (this.props.avatarColor === true && itemAlt)
       return colorByString(itemAlt)
     return undefined
@@ -168,7 +173,8 @@ export class ProvList extends React.Component<ProvListProps, ProvListState> {
             : itemsRoute(item)
           ) : null,
       divider: boolean = index < items.length - 1,
-      primaryField: string = this.props.primaryField ?? 'caption',
+      primaryField: ListField | null = this.props.primaryField ?? 'caption',
+      secondaryField: ListField | null = this.props.secondaryField ?? null,
       itemAltText: string | undefined = this.getItemAlt(item),
       avatarUrl: string | null = this.getItemAvatarUrl(item),
       avatarChildren: JSX.Element | JSX.Element[] | string | null = this.getItemAvatarChildren(item),
@@ -189,6 +195,7 @@ export class ProvList extends React.Component<ProvListProps, ProvListState> {
       routePath,
       divider,
       primaryField,
+      secondaryField,
       itemAltText,
       avatarUrl,
       avatarChildren,
@@ -225,8 +232,16 @@ export class ProvList extends React.Component<ProvListProps, ProvListState> {
             {items.map((item, index) => {
               const preparedItem: ProvListItemPrepared = this.prepareItem(item, index, items)
 
-              const PrimaryFieldComponent = this.props.primaryComponent || FieldItemData
-              const SecondaryFieldComponent = this.props.secondaryComponent || FieldItemData
+              const PrimaryFieldComponent = this.props.renderPrimaryField !== undefined
+                ? this.props.renderPrimaryField(item, preparedItem.primaryField)
+                : preparedItem.primaryField
+                  ? <FieldItemData item={item} field={preparedItem.primaryField} />
+                  : undefined
+              const SecondaryFieldComponent = this.props.renderSecondaryField !== undefined
+                ? this.props.renderSecondaryField(item, preparedItem.secondaryField)
+                : preparedItem.secondaryField
+                  ? <FieldItemData item={item} field={preparedItem.secondaryField} />
+                  : undefined
 
               const ListItemComponent: React.ElementType | undefined = this.props.itemComponent
               const ListItemElement = ListItemComponent !== undefined
@@ -271,10 +286,8 @@ export class ProvList extends React.Component<ProvListProps, ProvListState> {
                       )}
 
                       <ListItemText
-                        primary={<PrimaryFieldComponent item={item} field={preparedItem.primaryField} />}
-                        secondary={this.props.secondaryField && (
-                          <SecondaryFieldComponent item={item} field={this.props.secondaryField} />
-                        )}
+                        primary={PrimaryFieldComponent}
+                        secondary={SecondaryFieldComponent}
                       />
 
                       {(
@@ -316,8 +329,16 @@ export class ProvList extends React.Component<ProvListProps, ProvListState> {
             {items.map((item, index) => {
               const preparedItem: ProvListItemPrepared = this.prepareItem(item, index, items)
 
-              const PrimaryFieldComponent = this.props.primaryComponent || FieldItemData
-              const SecondaryFieldComponent = this.props.secondaryComponent || FieldItemData
+              const PrimaryFieldComponent = this.props.renderPrimaryField !== undefined
+                ? this.props.renderPrimaryField(item, preparedItem.primaryField)
+                : preparedItem.primaryField
+                  ? <FieldItemData item={item} field={preparedItem.primaryField} />
+                  : undefined
+              const SecondaryFieldComponent = this.props.renderSecondaryField !== undefined
+                ? this.props.renderSecondaryField(item, preparedItem.secondaryField)
+                : preparedItem.secondaryField
+                  ? <FieldItemData item={item} field={preparedItem.secondaryField} />
+                  : undefined
 
               const ListItemComponent: React.ElementType | undefined = this.props.itemComponent
               const ListItemElement = ListItemComponent !== undefined
@@ -390,17 +411,17 @@ export class ProvList extends React.Component<ProvListProps, ProvListState> {
                             }
                           </React.Fragment>
                         ) : undefined}
-                        title={<PrimaryFieldComponent item={item} field={preparedItem.primaryField} />}
+                        title={PrimaryFieldComponent}
                         titleTypographyProps={{
                           variant: 'h6',
                         }}
                       />
-                      {this.props.secondaryField && (
+                      {SecondaryFieldComponent !== undefined && SecondaryFieldComponent !== null && (
                         <CardContent sx={{
                           paddingTop: '4px',
                           paddingBottom: '16px'
                         }}>
-                          <SecondaryFieldComponent item={item} field={this.props.secondaryField} />
+                          {SecondaryFieldComponent}
                         </CardContent>
                       )}
                       {preparedItem.actions !== null && (
