@@ -5,18 +5,13 @@ const axios = require('axios')
 
 
 export function updateAuthorizationHeader(authorization: string | null): void {
-  if (request.defaults.headers === undefined) {
-    request.defaults.headers = {}
-  }
   if (authorization) {
-    request.defaults.headers['Authorization'] = authorization
+    request.defaults.headers.common['Authorization'] = authorization
   } else {
-    delete request.defaults.headers['Authorization']
+    delete request.defaults.headers.common['Authorization']
   }
 }
 
 
 export const request: AxiosInstance = axios.create()
-request.defaults.headers = {}
-
 updateAuthorizationHeader(aaa.getAuthorizationToken())
